﻿
using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;

/*  Transform a digital image into a Andy Warhol like image  */
/*                      modern art :-)                       */
/*                    www.mosismath.com                      */


namespace WindowsFormsApplication1
{

    public partial class MainWin : Form
    {

        Color nPixDark = Color.Blue;
        Color nPixBright = Color.White;

        public MainWin()
        {
            InitializeComponent();
            pbSource.Height = pbSource.Image.Height;
            pbSource.Width = pbSource.Image.Width;
            pbDest.Height = pbSource.Image.Height;
            pbDest.Width = pbSource.Image.Width;
        }

        private Bitmap ProcessImage(Bitmap bmpSource, int threshold)
        {
            int x, y, i, j;
            double R, G, B;
            Bitmap bmpDest = new Bitmap(pbDest.Image);
            for (x = 1; x < bmpSource.Width - 1; x++)
            {
                for (y = 1; y < bmpSource.Height - 1; y++)
                {
                    Color pix = bmpSource.GetPixel(x, y);
                    R = pix.R;
                    G = pix.G;
                    B = pix.B;

                    Color newPix;

                    if (Math.Sqrt(R * R + G * G + B * B) > threshold)
                    {
                        newPix = nPixBright;
                    }
                    else
                    {
                        newPix = nPixDark;
                    }
                    bmpDest.SetPixel(x, y, newPix);
                }
            }
            return bmpDest;
        }

        private Bitmap GrayScale(Bitmap bmpSource)
        {
            int x, y;
            double R, G, B;
            Bitmap bmpDest = new Bitmap(pbDest.Image);
           
            for (x = 1; x < bmpSource.Width - 1; x++)
            {
                for (y = 1; y < bmpSource.Height - 1; y++)
                {
                    Color pix1 = bmpSource.GetPixel(x, y);
                    double grayscale = (pix1.R + pix1.G + pix1.B) / 3.0;

                    R = grayscale;
                    G = grayscale;
                    B = grayscale;

                    if (R < 0)
                        R = 0;
                    else
                    {
                        if (R > 255)
                            R = 255;
                    }
                    if (G < 0)
                        G = 0;
                    else
                    {
                        if (G > 255)
                            G = 255;
                    }
                    if (B < 0)
                        B = 0;
                    else
                    {
                        if (B > 255)
                            B = 255;
                    }

                    // set the corresponding pixel in the destination bitmap
                    Color nPix = Color.FromArgb((int)(R), (int)(G), (int)(B));
                    bmpDest.SetPixel(x, y, nPix);
                }
            }
           return bmpDest;  
        }

        private void button1_Click(object sender, EventArgs e)
        {
            int threshold = 180;
            byte[] buffer;

            FileStream fileStream = new FileStream(Application.StartupPath + "\\Resources\\Fiat_500_blank.jpg", FileMode.Open, FileAccess.Read);
            try
            {
                int length = (int)fileStream.Length;  
                buffer = new byte[length];           
                int count;                           
                int sum = 0;                          

                // read until Read method returns 0 (end of the stream has been reached)
                while ((count = fileStream.Read(buffer, sum, length - sum)) > 0)
                    sum += count;  // sum is a buffer offset for next reading
            }
            finally
            {
                fileStream.Close();
            }
            MemoryStream imageStream = new MemoryStream(buffer, 0, buffer.Length);
            string tempString = System.Text.Encoding.ASCII.GetString(buffer);
            char[] bufferJpeg = new char[tempString.Length];
            tempString.CopyTo(0, bufferJpeg, 0, tempString.Length);
            imageStream.Position = 0;
            Bitmap bmpSource = new Bitmap(imageStream);
            Bitmap bmpDest1 = new Bitmap(pbDest.Image);
            Bitmap bmpDest2 = new Bitmap(pbDest.Image);
            bmpDest1 = GrayScale(bmpSource);
            bmpDest2 = ProcessImage(bmpDest1, threshold);
            pbDest.Image = bmpDest2;
            pbDest.Image.Save(Application.StartupPath + "\\Fiat_gr.jpg");
        }

        private void button2_Click(object sender, EventArgs e)
        {
            if (colorDialogdark.ShowDialog() == DialogResult.OK)
                nPixDark = Color.FromArgb((int)(colorDialogdark.Color.R), (int)(colorDialogdark.Color.G), (int)(colorDialogdark.Color.B));
        }

        private void button3_Click(object sender, EventArgs e)
        {
            if (colorDialogBright.ShowDialog() == DialogResult.OK)
                nPixBright = Color.FromArgb((int)(colorDialogBright.Color.R), (int)(colorDialogBright.Color.G), (int)(colorDialogBright.Color.B));
        }
    }
}
